==> dlcov-4.0.0.tar.gz: lib/repositories/config_repository.dart <==
import 'package:args/args.dart';

import '../core/app_constants.dart';
import '../models/config_model.dart';

/// Config repository
class ConfigRepository {
  ArgResults argResults;
  ConfigRepository(this.argResults);

  /// Execute usecase
  ConfigModel call() {
    late double percentage;
    late List<String> excludeSuffixes;
    late bool log;
    late String? packageName;
    late ArgResults? command;
    bool includeUntestedFiles = true;
    late String? lcovGen;

    try {
      command = argResults.command;

      final includeUntestedFilesInput =
          argResults[AppConstants.argIncludeUntestedFiles];

      includeUntestedFiles = includeUntestedFilesInput != null
          ? includeUntestedFilesInput == 'true'
          : true;

      lcovGen = argResults[AppConstants.argLcovGen];

      percentage =
          double.parse(argResults[AppConstants.argLongCoverage] ?? '0');
      final String excludesResult =
          argResults[AppConstants.argLongExcludeSuffix];
      excludeSuffixes = excludesResult
          .split(',')
          .map((e) => e.trim())
          .where((element) => element != '')
          .toList();
      log = argResults[AppConstants.argLongLog].toString().toLowerCase() ==
          'true';
      packageName = argResults[AppConstants.argLongPackageName];
    } catch (e) {
      print(e);
      rethrow;
    }

    return ConfigModel(
        percentage: percentage,
        excludeSuffixes: excludeSuffixes,
        log: log,
        packageName: packageName,
        command: command,
        includeUntestedFiles: includeUntestedFiles,
        lcovGen: lcovGen);
  }
}

==> dlcov-4.0.1.tar.gz: lib/repositories/config_repository.dart <==
import 'package:args/args.dart';

import '../core/app_constants.dart';
import '../models/config_model.dart';

/// Config repository
class ConfigRepository {
  ArgResults argResults;
  ConfigRepository(this.argResults);

  /// Execute usecase
  ConfigModel call() {
    late double percentage;
    late List<String> excludeSuffixes;
    late bool log;
    late String? packageName;
    late ArgResults? command;
    bool includeUntestedFiles = false;
    late String? lcovGen;

    try {
      command = argResults.command;

      final includeUntestedFilesInput =
          argResults[AppConstants.argIncludeUntestedFiles];

      includeUntestedFiles = includeUntestedFilesInput != null
          ? includeUntestedFilesInput == 'true'
          : false;

      lcovGen = argResults[AppConstants.argLcovGen];

      percentage =
          double.parse(argResults[AppConstants.argLongCoverage] ?? '0');
      final String excludesResult =
          argResults[AppConstants.argLongExcludeSuffix];
      excludeSuffixes = excludesResult
          .split(',')
          .map((e) => e.trim())
          .where((element) => element != '')
          .toList();
      log = argResults[AppConstants.argLongLog].toString().toLowerCase() ==
          'true';
      packageName = argResults[AppConstants.argLongPackageName];
    } catch (e) {
      print(e);
      rethrow;
    }

    return ConfigModel(
        percentage: percentage,
        excludeSuffixes: excludeSuffixes,
        log: log,
        packageName: packageName,
        command: command,
        includeUntestedFiles: includeUntestedFiles,
        lcovGen: lcovGen);
  }
}
